==> bibledit-0.9.tar.gz: bibledit-0.9/src/scripture.cpp <==
/*
** Copyright (C) 2003-2005 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/


#include "scripture.h"
#include "utilities.h"
#include "projectutils.h"
#include "bible.h"



Scripture::Scripture (const string & project)
{
  /*
     This object encapsulates a complete Scripture object.
   */
  // Read the books in this Scripture.
  for (unsigned int i = 0; i < NUMBER_OF_BIBLEBOOKS; i++) {
    string filename = projectutils_scripture_filename (project, index_to_biblebook (i));
    if (g_file_test (filename.c_str(), G_FILE_TEST_IS_REGULAR)) {
      books.push_back (index_to_biblebook (i));
      paths.push_back (filename);
    }
  }
}


Scripture::~Scripture ()
{
}


int
Scripture::get_index_of_book (const string & book)
{
  // Returns the index of book in the vector.
  for (unsigned int i = 0; i < books.size (); i++) {
    if (book == books[i])
      return i;
  }
  return -1;
}


/*
string Scripture::get_bibledit_data_directory() {
  // Ensure the directory exists.
  create_directory(bibledit_data_directory);
  // Return the value.
  return bibledit_data_directory;
}


string Scripture::get_backup_directory(int bookindex) {
  // Build the directory.
  string directory = Gxlib::build_filename (bibledit_data_directory, EnglishBookNames[bookindex] + "/backups");
  // Ensure it exists.
  create_directory(directory);
  // Return the value.
  return directory;
}
*/

==> bibledit-1.4.tar.gz: bibledit-1.4/src/scripture.cpp <==
/*
** Copyright (C) 2003-2005 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/


#include "scripture.h"
#include "utilities.h"
#include "projectutils.h"
#include "bible.h"



Scripture::Scripture (const ustring & project)
{
  /*
     This object encapsulates a complete Scripture object.
   */
  // Read the books in this Scripture.
  for (unsigned int i = 0; i < NUMBER_OF_BIBLEBOOKS; i++) {
    ustring filename = projectutils_scripture_filename (project, index_to_biblebook (i));
    if (g_file_test (filename.c_str(), G_FILE_TEST_IS_REGULAR)) {
      books.push_back (index_to_biblebook (i));
      paths.push_back (filename);
    }
  }
}


Scripture::~Scripture ()
{
}


int Scripture::get_index_of_book (const ustring & book)
{
  // Returns the index of book in the vector.
  for (unsigned int i = 0; i < books.size (); i++) {
    if (book == books[i])
      return i;
  }
  return -1;
}
